Changelog — Radon 1.4.2 documentation

# Changelog

## 1.4.2 (Jul 26, 2016)

- Use flake8-polyfill in order to keep compatibility with Flake8 2.x and 3.x: #92

## 1.4.0 (Jun 03, 2016)

- Add fingerprint to Code Climate issues: #88.
- Ensure the Code Climate issues have integer location values: #89.
- Count `async def`, `async for` and `async with` towards CC: #90.

## 1.3.0 (Mar 02, 2016)

- Modify behaviour of `--show-closures`. Now inner classes are added to the output as well: #79.
- Fix bug in `is_multiline_string`: #81.

## 1.2.2 (Jul 09, 2015)

- Add plugin for flake8 tool: #76.

## 1.2.1 (May 07, 2015)

- The XML output now contains the line numbers: #75.

## 1.2 (Jan 16, 2015)

- Backwards incompatible change regarding to CC of lambda functions and nested functions: #68.
- Fix the bug that caused classes with only one method have a CC of 2: #70.

## 1.1 (Sep 6, 2014)

- Make -n, –min and -x, –max effective everywhere (in JSON and XML exporting too): #62.
- Fix the bug that prevented JSON/XML export when one file had errors during the analysis: #63.
- Add an explanations and various examples to the docs so that programmatical use of Radon is easier: #64.

## 1.0 (Aug 15, 2014)

- Add `--xml` option to cc command: #49.
- Officialy support Python 3.4.
- Remove pathfinder: #59.
- Reduce drastically unit-testing time: #56.
- Update documentation (http://radon.readthedocs.org/en/latest/): #60.

## 0.5.3 (Aug 1, 2014)

- Encode the source code to bytes if that’s possible (Python 3).
- Show help if no command is given.
- Add support to read code from stdin (thanks @io41): #55.
- Move the tests inside the radon directory: #58.

## 0.5.2 (Jul 24, 2014)

- Fix while ... else bug: #53.

## 0.5.1 (Mar 4, 2014)

- Fix –total-average behavior.

## 0.5 (Feb 17, 2014)

- Add -i, –ignore option to ignore directories: #39.
- Add –no-assert option to cc command to avoid assert statements: #42.
- Add -j, –json option to raw command (thanks @cjav): #45.
- Add –total-average option to cc command: #44.
- Add –version global option: #47.

## 0.4.5 (Dec 16, 2013)

- Baker is replaced with mando: https://github.com/rubik/mando.

## 0.4.4 (Nov 20, 2013)

- Add -j option to cc command: #33.
- Use pathfinder and improve iter_filenames: #31.
- Complete the documentation: #18.
- Add -s, –summarize option to raw command (thanks @jsargiot): #36.

## 0.4.2 (Jun 25, 2013)

- raw command failed on almost-empty files: #29.

## 0.4.1 (Jun 16, 2013)

- Turn off colors when not printing to a tty (thanks @kennknowles): #26.
- Fixed #27 (endline could be float(‘-inf’) sometimes).

## 0.4 (Apr 26, 2013)

- Added -s option to mi command: #19.
- Added -o option to cc command to sort output: #20.
- Added endline attribute to Function and Class objects: #25.

## 0.3 (Nov 2, 2012)

- Code coverage to 100%, runs from Python 2.6 up to 3.3 and on PyPy as well.
- Created a documentation at https://radon.readthedocs.org: #5.
- Made the codebase compatible with PyPy: #9.
- Ported cli.py to Python 3: #14.
- More tests: #15.
- Minor fixes: #11, #12, #13, #17.

## 0.2 (Oct 11, 2012)

Initial version.

## 0.1 (Never)

There was no 0.1.